<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
	<xsl:template match="/">
		<HTML>
			<HEAD>
				<TITLE>
					<xsl:value-of select="pjm5StatementGet/Statement/FileAs" />
				</TITLE>
				<xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
			</HEAD>
			<BODY >
				<xsl:value-of select="adf:GetHeader(pjm5StatementGet/Statement)"  disable-output-escaping="yes"/>
				<br />
				<xsl:apply-templates select="//Statement"/>
				<br/>
				<xsl:choose>
					<xsl:when test="//Line/ID">
					
						<table border="1" cellspacing="0" cellpadding="4">
							<tr>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Описание
                    </xsl:when>
                    <xsl:otherwise>
                      Description
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Количество
                  </xsl:when>
                  <xsl:otherwise>
                    Amount
                  </xsl:otherwise>
                </xsl:choose>
              </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Ед.измерения
                    </xsl:when>
                    <xsl:otherwise>
                      Unit Of Measure
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена
                    </xsl:when>
                    <xsl:otherwise>
                      Price
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      НДС
                    </xsl:when>
                    <xsl:otherwise>
                      VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма
                    </xsl:when>
                    <xsl:otherwise>
                      Total
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
							</tr>
							<xsl:for-each select="//Line">
								<xsl:apply-templates select="."/>
							</xsl:for-each>
						</table>

					</xsl:when>
					<xsl:otherwise>	</xsl:otherwise>
				</xsl:choose>

				<xsl:value-of select="adf:GetFooter(pjm5StatementGet/Statement)"  disable-output-escaping="yes"/>

			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="Line">
		<tr>
			<td>
				<xsl:value-of select="Description"/>
			</td>
			<td align="right">
				<xsl:variable name="x" select="Amount"/>
				<xsl:value-of select="format-number($x,'0.##')"/>
			</td>
			<td>
				<xsl:value-of select="UOMCode"/>
			</td>
			<td align="right">
				<xsl:variable name="y" select="PriceWithVAT"/>
				<xsl:value-of select="format-number($y,'0.##')"/>
			</td>
			<td align="right">
				<xsl:variable name="z" select="VAT"/>
				<xsl:value-of select="format-number($z,'0.##')"/>
			</td>
			<td align="right">
				<xsl:variable name="a" select="SumWithVAT"/>
				<xsl:value-of select="format-number($a,'0.##')"/>
			</td>
			<td>
				<xsl:apply-templates select="//Statement/CurrencyCode"/>
				</td>
		</tr>
	</xsl:template>

	<xsl:template match="CurrencyCode">
		<xsl:value-of select="."/>
	</xsl:template>
	<xsl:template match="Statement">
		<table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
			
			<tr>
				<td>
					
					<xsl:choose>
						<xsl:when test="Date">
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Дата:
                  </xsl:when>
                  <xsl:otherwise>
                    Date:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>

					<xsl:choose>
						<xsl:when test="ContractNumber">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Договор:
                  </xsl:when>
                  <xsl:otherwise>
                    Project Code:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="ContractNumber"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="CustomerCompanyID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Покупатель:
                  </xsl:when>
                  <xsl:otherwise>
                    Customer:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(CustomerCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
			
					<xsl:choose>
						<xsl:when test="SupplierCompanyID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Поставщик:
                  </xsl:when>
                  <xsl:otherwise>
                    Supplier:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(SupplierCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="PeriodStart">
							<br />
							<strong> 
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Период:
                </xsl:when>
                <xsl:otherwise>
                  Period:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
							<xsl:value-of select="adf:FormatXmlDate(PeriodStart,'d')"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
					<strong> - </strong>
					<xsl:choose>
						<xsl:when test="PeriodEnd">
							<xsl:value-of select="adf:FormatXmlDate(PeriodEnd,'d')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>

				</td>
			</tr>

			<tr>
						<td>
							<xsl:choose>
								<xsl:when test="TotalWithVAT">
									<br />
									<strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Сумма:
                      </xsl:when>
                      <xsl:otherwise>
                        Total:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
									<xsl:variable name="x" select="TotalWithVAT"/>
									<xsl:value-of select="format-number($x,'0.##')"/>
								</xsl:when>
								<xsl:otherwise>	 </xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td>
					<xsl:choose>
						<xsl:when test="CurrencyCode">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта:
                  </xsl:when>
                  <xsl:otherwise>
                    Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="CurrencyCode"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>